Welcome to ClientVPS Mirrors

Help for package tlgarima

Package {tlgarima}


Type: Package
Title: The Topp–Leone Garima Distribution
Version: 0.1.0
Description: Density, distribution function, quantile function, and random generating function of the Topp–Leone Garima distribution based on Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025)<doi:10.1134/S1995080225608471>. In addition, maximum likelihood estimation for the Topp–Leone Garima distribution is provided.
License: GPL-3
Language: en-US
Encoding: UTF-8
Imports: stats, lamW
RoxygenNote: 7.3.2
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-06-02 13:33:54 UTC; User
Author: Arin Boonmeekham [aut], Thidaporn Supapakorn [aut], Winai Bodhisuwan [aut], Atchanut Rattanalertnusorn [cre, ctb]
Maintainer: Atchanut Rattanalertnusorn <atchanut_r@rmutt.ac.th>
Repository: CRAN
Date/Publication: 2026-06-08 17:50:02 UTC

The Topp–Leone Garima Distribution (TLGa)

Description

Density, distribution function, quantile function, and random generation function for TLGa distribution with two parameters (alpha and theta). The TLGa distribution is first presented by Arin Boonmeekham, Thidaporn Supapakorn, and Winai Bodhisuwan. See details in references.

Usage

dTLGa(x, alpha, theta, log = FALSE)

pTLGa(q, alpha, theta, lower.tail = TRUE, log.p = FALSE)

qTLGa(p, alpha, theta)

rTLGa(n, alpha, theta)

Arguments

x, q

vector of quantile.

alpha

shape parameter of the Topp–Leone generator of distributions, where \alpha > 0.

theta

shape parameter of the Garima distribution, where \theta > 0.

log, log.p

logical; (default = FALSE), if TRUE, then probabilities are given as log(p).

lower.tail

logical; if TRUE (default), probabilities are P[ X \le x], otherwise, P[X > x].

p

vector of probabilities.

n

number of observations.

Value

dTLGa gives the density, pTLGa gives the distribution function, qTLGa gives the quantile function, rTLGa generates random samples.

References

Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025). The Topp–Leone Garima Distribution: Properties and Application. Lobachevskii Journal of Mathematics, 46(7), 3510-3521. doi:10.1134/S1995080225608471.

Examples

NULL



x <- seq(1,10,by=0.1)
x
fx <- dTLGa(x,alpha = 1, theta = 2)
fx
logfx <- dTLGa(x,alpha = 1, theta = 2,log = TRUE)
logfx



x <- seq(1,10,by=0.1)
x
Fx <- pTLGa(q=x ,alpha = 1, theta = 0.8)
Fx     #P(X<x)
Sx <- pTLGa(q=x ,alpha = 1, theta = 0.8, lower.tail = FALSE) # Survival function
Sx     #P(X>x) or 1-Fx



require(lamW)
x <- rTLGa(20,alpha=1.5,theta=3)
x
p <- pTLGa(x,alpha = 1.5, theta = 3)
p
q <- qTLGa(p,alpha=1.5,theta = 3)
q    # The value of q is equal to x.



require(lamW)
x <- rTLGa(50,alpha=2,theta=1.5)
x



Maximum Likelihood Estimation

Description

A maximum likelihood estimation function for the Topp–Leone Garima Distribution (TLGa distribution ).

Usage

mleTLGa(x, param, method = "L-BFGS-B")

Arguments

x

data vector

param

parameter vector of the TLGa distribution.

method

a numerical optimization method, that is, the L-BFGS-B algorithm.

Value

a list of output(variables) as follows: estalpha is the estimated parameter alpha, esttheta is the estimated parameter theta, negll_value is the negative Loglikelihood function, stderr_of_estalpha is the standard error of the estimated parameter alpha. stderr_of_esttheta is the standard error of the estimated parameter theta.

References

Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025). The Topp–Leone Garima Distribution: Properties and Application. Lobachevskii Journal of Mathematics, 46(7), 3510-3521. doi:10.1134/S1995080225608471.

Examples

x <- rTLGa(100,alpha = 1, theta = 2)
guess_params <- c(0.8, 1.5)
mleTLGa(x,param=guess_params)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.