| Title: | The Topp–Leone Garima Distribution |
|---|---|
| Description: | Density, distribution function, quantile function, and random generating function of the Topp–Leone Garima distribution based on Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025)<doi:10.1134/S1995080225608471>. In addition, maximum likelihood estimation for the Topp–Leone Garima distribution is provided. |
| Authors: | Arin Boonmeekham [aut], Thidaporn Supapakorn [aut], Winai Bodhisuwan [aut], Atchanut Rattanalertnusorn [cre, ctb] |
| Maintainer: | Atchanut Rattanalertnusorn <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-06-09 12:20:14 UTC |
| Source: | https://github.com/cran/tlgarima |
A maximum likelihood estimation function for the Topp–Leone Garima Distribution (TLGa distribution ).
mleTLGa(x, param, method = "L-BFGS-B")mleTLGa(x, param, method = "L-BFGS-B")
x |
data vector |
param |
parameter vector of the TLGa distribution. |
method |
a numerical optimization method, that is, the L-BFGS-B algorithm. |
a list of output(variables) as follows:
estalpha is the estimated parameter alpha,
esttheta is the estimated parameter theta,
negll_value is the negative Loglikelihood function,
stderr_of_estalpha is the standard error of the estimated parameter alpha.
stderr_of_esttheta is the standard error of the estimated parameter theta.
Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025). The Topp–Leone Garima Distribution: Properties and Application. Lobachevskii Journal of Mathematics, 46(7), 3510-3521. doi:10.1134/S1995080225608471.
x <- rTLGa(100,alpha = 1, theta = 2) guess_params <- c(0.8, 1.5) mleTLGa(x,param=guess_params)x <- rTLGa(100,alpha = 1, theta = 2) guess_params <- c(0.8, 1.5) mleTLGa(x,param=guess_params)
Density, distribution function, quantile function, and random generation function
for TLGa distribution with two parameters (alpha and theta).
The TLGa distribution is first presented by Arin Boonmeekham, Thidaporn Supapakorn,
and Winai Bodhisuwan. See details in references.
dTLGa(x, alpha, theta, log = FALSE) pTLGa(q, alpha, theta, lower.tail = TRUE, log.p = FALSE) qTLGa(p, alpha, theta) rTLGa(n, alpha, theta)dTLGa(x, alpha, theta, log = FALSE) pTLGa(q, alpha, theta, lower.tail = TRUE, log.p = FALSE) qTLGa(p, alpha, theta) rTLGa(n, alpha, theta)
x, q
|
vector of quantile. |
alpha |
shape parameter of the Topp–Leone generator of distributions, where |
theta |
shape parameter of the Garima distribution, where |
log, log.p
|
logical; (default = |
lower.tail |
logical; if |
p |
vector of probabilities. |
n |
number of observations. |
dTLGa gives the density,
pTLGa gives the distribution function,
qTLGa gives the quantile function,
rTLGa generates random samples.
Boonmeekham, A., Supapakorn, T., & Bodhisuwan, W. (2025). The Topp–Leone Garima Distribution: Properties and Application. Lobachevskii Journal of Mathematics, 46(7), 3510-3521. doi:10.1134/S1995080225608471.
NULL x <- seq(1,10,by=0.1) x fx <- dTLGa(x,alpha = 1, theta = 2) fx logfx <- dTLGa(x,alpha = 1, theta = 2,log = TRUE) logfx x <- seq(1,10,by=0.1) x Fx <- pTLGa(q=x ,alpha = 1, theta = 0.8) Fx #P(X<x) Sx <- pTLGa(q=x ,alpha = 1, theta = 0.8, lower.tail = FALSE) # Survival function Sx #P(X>x) or 1-Fx require(lamW) x <- rTLGa(20,alpha=1.5,theta=3) x p <- pTLGa(x,alpha = 1.5, theta = 3) p q <- qTLGa(p,alpha=1.5,theta = 3) q # The value of q is equal to x. require(lamW) x <- rTLGa(50,alpha=2,theta=1.5) xNULL x <- seq(1,10,by=0.1) x fx <- dTLGa(x,alpha = 1, theta = 2) fx logfx <- dTLGa(x,alpha = 1, theta = 2,log = TRUE) logfx x <- seq(1,10,by=0.1) x Fx <- pTLGa(q=x ,alpha = 1, theta = 0.8) Fx #P(X<x) Sx <- pTLGa(q=x ,alpha = 1, theta = 0.8, lower.tail = FALSE) # Survival function Sx #P(X>x) or 1-Fx require(lamW) x <- rTLGa(20,alpha=1.5,theta=3) x p <- pTLGa(x,alpha = 1.5, theta = 3) p q <- qTLGa(p,alpha=1.5,theta = 3) q # The value of q is equal to x. require(lamW) x <- rTLGa(50,alpha=2,theta=1.5) x